@@ -59,7 +59,7 @@ if t.TYPE_CHECKING:
     # avoid circular import at runtime
     from ansible.executor.task_queue_manager import FinalQueue
 
-_LIBC = ctypes.cdll.LoadLibrary('msys-2.0.dll')
+_LIBC = ctypes.cdll.LoadLibrary(ctypes.util.find_library('c'))
 # Set argtypes, to avoid segfault if the wrong type is provided,
 # restype is assumed to be c_int
 _LIBC.wcwidth.argtypes = (ctypes.c_wchar,)
